@@ -71,7 +71,7 @@ class MdDevice(object):
                     if self.state != "ok":
                         parseMessage = False
                         failRegex = re.compile(
-                            '.+?recovery =\s+?(\d+?\.\d+?%)\s+?\((\d+?\/\d+?)\)\s+?finish=(\d+?\.\d+?.+?)\s+?speed=(.+)')
+                            '.+?re.+? =\s+?(\d+?\.\d+?%)\s+?\((\d+?\/\d+?)\)\s+?finish=(\d+?\.\d+?.+?)\s+?speed=(.+)')
                         for line in readfile("/proc/mdstat").split('\n'):
                             if line.startswith(self.file):
                                 parseMessage = True
